# Product card block

**Product card** is a logically and functionally independent reusable page component ([block](https://en.bem.info/methodology/key-concepts/#block)) which allows the user to add the product to the cart and/or navigate to the product page.

By default the product card has a vertical layout and consists of three blocks:
- header (contains product image);
- main (contains product name);
- footer (contains "Add to cart" button).

HTML implementation:

```html
<div class="product-card" role="listitem" itemscope itemtype="http://schema.org/Product">
    <div class="product-card__main">
        <h3 class="product-card__heading" itemprop="name">
            <a href="#" class="product-card__heading-link">Product name</a>
        </h3>
    </div>
    <footer class="product-card__footer" itemprop="offers" itemscope itemtype="http://schema.org/Offer">
        <span class="product-card__price-wrap" aria-label="$99.9">
            <span class="product-card__price-currency" itemprop="priceCurrency" content="USD" aria-hidden="true">$</span>
            <span class="product-card__price" itemprop="price" aria-hidden="true">99.9</span>
        </span>
        <button class="product-card__offer-button">Add to cart</button>
    </footer>
    <header class="product-card__header">
        <a href="#" class="product-card__image-link">
            <img class="product-card__image" src="" alt="Image description" itemprop="image">
        </a>
    </header>
</div>

```

HTML implementation without microdata:

```html
<div class="product-card">
    <div class="product-card__main">
        <h3 class="product-card__heading">
            <a href="#" class="product-card__heading-link">Product name</a>
        </h3>
    </div>
    <footer class="product-card__footer">
        <span class="product-card__price-wrap" aria-label="$99.9">
            <span class="product-card__price-currency" aria-hidden="true">$</span>
            <span class="product-card__price" aria-hidden="true">99.9</span>
        </span>
        <button class="product-card__offer-button">Add to cart</button>
    </footer>
    <header class="product-card__header">
        <a href="#" class="product-card__image-link">
            <img class="product-card__image" src="" alt="Image description">
        </a>
    </header>
</div>

```

## Using

Add `@import 'product-card.css';` file to your CSS entry point or `@import "product-card-export.css";` if you need modifiers.

## Modification methods

The default behavior and appereance of the button block can modified using these BEM [modification methods](https://en.bem.info/methodology/block-modification/):

* [Modifiers](https://en.bem.info/methodology/block-modification/#using-a-modifier-to-change-a-block)
* [Mixes](https://en.bem.info/methodology/block-modification/#using-a-mix-to-change-a-block)
* [Redefinition levels](https://en.bem.info/methodology/block-modification/#using-redefinition-levels-to-change-a-block)

### Modification by modifiers

Use a [modifier](https://en.bem.info/methodology/block-modification/#using-a-modifier-to-change-a-block) to change one specific instance of a block without affecting surrounding blocks.

The **Product card** block has the following predefined modifiers:

```sh
.product-card_horizontal-rows   # three blocks (header, main, footer) in line
.product-card_horizontal-cols   # product card is still horisontal but it has two columns: header section on the left, main and offer sections on the right in one column
```

Let's change the **Product card** block layout to horizontal with three blocks in line by adding `.product-card_horizontal-rows` modifier.

HTML implementation:

```html
<div class="product-card product-card_horizontal-row">
…
</div>

```

You can add your custom modifiers on project [redefinition level](#Modification-by-redefinition-levels).

### Modification by mixes

Use a [mix](https://en.bem.info/methodology/block-modification/#using-a-mix-to-change-a-block) to place additional BEM entities on the same DOM node as the block to combine the behavior and style of multiple entities without duplicating code and affecting surrounding blocks.

Let's place a specific **Product card** block on the second position in a flex context regardless of its position in the HTML code.

HTML implementation:

```html
<div class="product-card product-card_always-second">
…
</div>

```

CSS implementation:

```css
.product-card_always-second {
    order: 1; /* default value is 0*/
}
```

### Modification by redefinition levels

Use [redefinition levels](https://ru.bem.info/methodology/redefinition-levels) to change the default look of the **Product card** block to fit your project design.

Changes are made to the block by combining the block custom and regular properties from different redefinition levels. Blocks can be [extended and redefined](https://en.bem.info/methodology/redefinition-levels/#changing-the-block-implementation) on a separate level and applied during assembly.

Redefining is changing the existing (predefined) custom properties of the **Product card** block while extending is adding new properties to it.

File structure with the new rules for **Product card** (product-card.css) on the project.blocks level:

```sh
project/
    library.blocks/
        product-card/
            product-card.css  # main CSS implementation of the product card
    project.blocks/
        product-card/
            product-card.css  # redefinition on the project level
```

The **Product card** block has the next predefined custom properties:

```css
:root {
  --product-card-layout:
      "product-card-header"
      "product-card-main"
      "product-card-footer";
}
```

Let's change the **Product card** block layout by redefining the predefined `--product-card-layout` custom property value on the project level (project.blocks).

CSS implementation:

```css
:root {
  --product-card-layout:
      "product-card-header product-card-header"
      "product-card-main product-card-footer";
}
```

As a result, rules from both redefinition levels should be compiled by your build script and applied to the **Product card** block.
